@@ -116,8 +116,10 @@ class BaseField(object):
 
 # Concrete fields
 class StringField(BaseField):
-    def __init__(self, required=False, default=None, repeated=False, choices=None, max_len=500):
+    def __init__(self, required=False, default=None, repeated=False, choices=None, max_len=500,exactly_len=None,min_len=None):
         super(StringField, self).__init__(required, default, repeated, choices)
+        self.min_len = min_len
+        self.exactly_len = exactly_len
         self.max_len = max_len
 
     def set_options(self, model_property):
@@ -126,9 +128,17 @@ class StringField(BaseField):
 
 
     def validate_field(self, value):
-        if self.max_len and value and len(value) > self.max_len:
-            return _('Has %(len)s characters and it must have less than %(max_len)s') % {'len': len(value),
-                                                                                         'max_len': self.max_len}
+        if value is not None:
+            len_value = len(value)
+            if self.exactly_len is not None and len_value !=self.exactly_len:
+                return _('Has %(len)s characters and it must have exactly %(exactly_len)s') % {'len': len_value,
+                                                                                             'exactly_len': self.exactly_len}
+            if self.max_len and len_value > self.max_len:
+                return _('Has %(len)s characters and it must have %(max_len)s or less') % {'len': len_value,
+                                                                                             'max_len': self.max_len}
+            if self.min_len and len_value < self.min_len:
+                return _('Has %(len)s characters and it must have %(min_len)s or more') % {'len': len_value,
+                                                                                             'min_len': self.min_len}
 
         return super(StringField, self).validate_field(value)
 
@@ -166,7 +176,7 @@ class KeyField(BaseField):
                         value = ndb.Key(urlsafe=value)
                     except:
                         return _('Invalid key')
-            elif isinstance(value,Model) and value.key:
+            elif isinstance(value, Model) and value.key:
                 return
         return super(KeyField, self).validate_field(value)
 
@@ -186,7 +196,7 @@ class KeyField(BaseField):
                         value = ndb.Key(urlsafe=value)
                     except:
                         raise Exception('Invalid key')
-            elif isinstance(value,Model):
+            elif isinstance(value, Model):
                 return value.key
         return super(KeyField, self).normalize_field(value)
 
@@ -222,7 +232,7 @@ class IntegerField(BaseField):
     def normalize_field(self, value):
         if value == '':
             value = None
-        if isinstance(value,int):
+        if isinstance(value, int):
             return value
         elif value is not None:
             value = int(i18n.get_i18n().parse_decimal(value))
@@ -245,7 +255,7 @@ class BooleanField(BaseField):
     def normalize_field(self, value):
         if value == '':
             value = None
-        if isinstance(value,bool):
+        if isinstance(value, bool):
             return value
         elif value is not None:
             value = value.upper()
@@ -280,7 +290,7 @@ class FloatField(BaseField):
             return _('Must be a number')
 
     def normalize_field(self, value):
-        if isinstance(value,(int,float)):
+        if isinstance(value, (int, float)):
             return value
         if value == '':
             value = None
@@ -328,7 +338,7 @@ class DecimalField(BaseField):
 
 
     def normalize_field(self, value):
-        if isinstance(value,Decimal):
+        if isinstance(value, Decimal):
             return value
         if value == '':
             value = None
@@ -464,4 +474,27 @@ class Form(object):
         return {k: _localize(k, v) for k, v in self._fields.iteritems()}
 
 
+class CepField(BaseField):
+    def validate_field(self, value):
+        if value:
+            value = value.replace('-', '')
+            if len(value) != 8:
+                return _('CEP must have exactly 8 characters')
+            try:
+                int(value)
+            except:
+                return _('CEP must contain only numbers')
+        return super(CepField, self).validate_field(value)
 
+    def normalize_field(self, value):
+        if value:
+            return value.replace('-', '')
+        elif value == '':
+            value = None
+        return super(CepField, self).normalize_field(value)
+
+
+    def localize(self, value):
+        if value:
+            return '%s-%s' % (value[:5], value[5:])
+        return super(CepField, self).localize(value)
\ No newline at end of file
